==> dualKS_1.12.0.zip: dualKS/doc/dualKS.R <==
###################################################
### chunk number 1: 
###################################################
#line 99 "dualKS.rnw"
options(width=70, scipen=999)


###################################################
### chunk number 2: 
###################################################
#line 103 "dualKS.rnw"
library("dualKS")
data("dks")
pData(eset)


###################################################
### chunk number 3: 
###################################################
#line 120 "dualKS.rnw"
	tr <- dksTrain(eset, class=1, type="up")


###################################################
### chunk number 4: 
###################################################
#line 133 "dualKS.rnw"
	cl <- dksSelectGenes(tr, n=100)


###################################################
### chunk number 5: 
###################################################
#line 142 "dualKS.rnw"
	pr <- dksClassify(eset, cl)
	summary(pr, actual=pData(eset)[,1])
	show(pr)


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 168 "dualKS.rnw"
## plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 7: 
###################################################
#line 174 "dualKS.rnw"
plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 8: 
###################################################
#line 213 "dualKS.rnw"
	pr <- dksClassify(eset, cl, rescale=TRUE)
	summary(pr, actual=pData(eset)[,1])


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 220 "dualKS.rnw"
## 	plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 10: 
###################################################
#line 226 "dualKS.rnw"
	plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 244 "dualKS.rnw"
## 
## sc <- KS(exprs(eset)[,1], cl@genes.up)
## plot(sc$runningSums[,1], type='l', ylab="KS sum", ylim=c(-1200,1200), col="red")
## par(new=TRUE)
## plot(sc$runningSums[,2], type='l', ylab="KS sum", ylim=c(-1200,1200), col="green")
## par(new=TRUE)
## plot(sc$runningSums[,3], type='l', ylab="KS sum", ylim=c(-1200,1200), col="blue")
## legend("topright", col=c("red", "green", "blue"), lwd=2, legend=colnames(sc$runningSums))


###################################################
### chunk number 12: 
###################################################
#line 261 "dualKS.rnw"
sc <- KS(exprs(eset)[,1], cl@genes.up)
plot(sc$runningSums[,1], type='l', ylab="KS sum", ylim=c(-1200,1200), col="red")
par(new=TRUE)
plot(sc$runningSums[,2], type='l', ylab="KS sum", ylim=c(-1200,1200), col="green")
par(new=TRUE)
plot(sc$runningSums[,3], type='l', ylab="KS sum", ylim=c(-1200,1200), col="blue")
legend("topright", col=c("red", "green", "blue"), lwd=2, legend=colnames(sc$runningSums))


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 311 "dualKS.rnw"
## tr <- dksTrain(exprs(eset), class=pData(eset)[,1], type="up", weights=TRUE)
## cl <- dksSelectGenes(tr, n=100)
## pr <- dksClassify(exprs(eset), cl)
## plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 14: 
###################################################
#line 324 "dualKS.rnw"
tr <- dksTrain(exprs(eset), class=pData(eset)[,1], type="up", weights=TRUE)
cl <- dksSelectGenes(tr, n=100)
pr <- dksClassify(exprs(eset), cl)
plot(pr, actual=pData(eset)[,1])


###################################################
### chunk number 15:  eval=FALSE
###################################################
## #line 349 "dualKS.rnw"
## wt <- dksWeights(eset, class=1)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 356 "dualKS.rnw"
## tr <- dksTrain(exprs(eset), class=1, weights=wt)


###################################################
### chunk number 17:  eval=FALSE
###################################################
## #line 393 "dualKS.rnw"
## 
## ix.n <- which(pData(eset)[,1] == "normal")
## data <- exprs(eset)
## data.m <- apply(data[,ix.n], 1, mean, na.rm=TRUE)
## 


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 404 "dualKS.rnw"
## data <- data[,-ix.n]
## data.r <- sweep(data, 1, data.m, "/")


###################################################
### chunk number 19:  eval=FALSE
###################################################
## #line 412 "dualKS.rnw"
## data.r <- log(data.r, 2)
## tr <- dksTrain(data.r, class=pData(eset)[-ix.n,1], type="both")
## cl <- dksSelectGenes(tr, n=100)
## pr <- dksClassify(data.r, cl)
## plot(pr, actual=pData(eset)[-ix.n,1])


###################################################
### chunk number 20: 
###################################################
#line 422 "dualKS.rnw"
ix.n <- which(pData(eset)[,1] == "normal")
data <- exprs(eset)
data.m <- apply(data[,ix.n], 1, mean, na.rm=TRUE)
data <- data[,-ix.n]
data.r <- sweep(data, 1, data.m, "/")
data.r <- log(data.r, 2)

tr <- dksTrain(data.r, class=pData(eset)[-ix.n,1], type="both")
cl <- dksSelectGenes(tr, n=100)
pr <- dksClassify(data.r, cl)
plot(pr, actual=pData(eset)[-ix.n,1])


###################################################
### chunk number 21: 
###################################################
#line 441 "dualKS.rnw"
summary(pr, actual=pData(eset)[-ix.n,1])
show(pr)


###################################################
### chunk number 22: 
###################################################
#line 469 "dualKS.rnw"
pvalue.f <- pv.f


###################################################
### chunk number 23: 
###################################################
#line 473 "dualKS.rnw"
pvalue.f <- dksPerm(eset, 1, type="both", samples=500)


###################################################
### chunk number 24: 
###################################################
#line 483 "dualKS.rnw"
pvalue.f(pr@predictedScore)


###################################################
### chunk number 25:  eval=FALSE
###################################################
## #line 517 "dualKS.rnw"
## cls <- factor(sample(pData(eset)[,1], 300, replace=TRUE))
## sig.up <- sample(rownames(exprs(eset), 300))
## classifier <- dksCustomClass(upgenes=sig.up, upclass=cls)
## pr.cust <- dksClassify(eset, classifier)


###################################################
### chunk number 26: 
###################################################
#line 536 "dualKS.rnw"
results <- data.frame(pr@predictedClass, pr@scoreMatrix)
results

==> dualKS_1.28.0.zip: dualKS/doc/dualKS.R <==
### R code from vignette source 'dualKS.rnw'

###################################################
### code chunk number 1: dualKS.rnw:98-99
###################################################
options(width=70, scipen=999)


###################################################
### code chunk number 2: dualKS.rnw:102-105
###################################################
library("dualKS")
data("dks")
pData(eset)


###################################################
### code chunk number 3: dualKS.rnw:119-120
###################################################
	tr <- dksTrain(eset, class=1, type="up")


###################################################
### code chunk number 4: dualKS.rnw:132-133
###################################################
	cl <- dksSelectGenes(tr, n=100)


###################################################
### code chunk number 5: dualKS.rnw:141-144
###################################################
	pr <- dksClassify(eset, cl)
	summary(pr, actual=pData(eset)[,1])
	show(pr)


###################################################
### code chunk number 6: dualKS.rnw:167-168 (eval = FALSE)
###################################################
## plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 7: dualKS.rnw:173-174
###################################################
plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 8: dualKS.rnw:212-214
###################################################
	pr <- dksClassify(eset, cl, rescale=TRUE)
	summary(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 9: dualKS.rnw:219-220 (eval = FALSE)
###################################################
## 	plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 10: dualKS.rnw:225-226
###################################################
	plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 11: dualKS.rnw:243-251 (eval = FALSE)
###################################################
## 
## sc <- KS(exprs(eset)[,1], cl@genes.up)
## plot(sc$runningSums[,1], type='l', ylab="KS sum", ylim=c(-1200,1200), col="red")
## par(new=TRUE)
## plot(sc$runningSums[,2], type='l', ylab="KS sum", ylim=c(-1200,1200), col="green")
## par(new=TRUE)
## plot(sc$runningSums[,3], type='l', ylab="KS sum", ylim=c(-1200,1200), col="blue")
## legend("topright", col=c("red", "green", "blue"), lwd=2, legend=colnames(sc$runningSums))


###################################################
### code chunk number 12: dualKS.rnw:260-267
###################################################
sc <- KS(exprs(eset)[,1], cl@genes.up)
plot(sc$runningSums[,1], type='l', ylab="KS sum", ylim=c(-1200,1200), col="red")
par(new=TRUE)
plot(sc$runningSums[,2], type='l', ylab="KS sum", ylim=c(-1200,1200), col="green")
par(new=TRUE)
plot(sc$runningSums[,3], type='l', ylab="KS sum", ylim=c(-1200,1200), col="blue")
legend("topright", col=c("red", "green", "blue"), lwd=2, legend=colnames(sc$runningSums))


###################################################
### code chunk number 13: dualKS.rnw:310-314 (eval = FALSE)
###################################################
## tr <- dksTrain(exprs(eset), class=pData(eset)[,1], type="up", weights=TRUE)
## cl <- dksSelectGenes(tr, n=100)
## pr <- dksClassify(exprs(eset), cl)
## plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 14: dualKS.rnw:323-327
###################################################
tr <- dksTrain(exprs(eset), class=pData(eset)[,1], type="up", weights=TRUE)
cl <- dksSelectGenes(tr, n=100)
pr <- dksClassify(exprs(eset), cl)
plot(pr, actual=pData(eset)[,1])


###################################################
### code chunk number 15: dualKS.rnw:348-349 (eval = FALSE)
###################################################
## wt <- dksWeights(eset, class=1)


###################################################
### code chunk number 16: dualKS.rnw:355-356 (eval = FALSE)
###################################################
## tr <- dksTrain(exprs(eset), class=1, weights=wt)


###################################################
### code chunk number 17: dualKS.rnw:392-397 (eval = FALSE)
###################################################
## 
## ix.n <- which(pData(eset)[,1] == "normal")
## data <- exprs(eset)
## data.m <- apply(data[,ix.n], 1, mean, na.rm=TRUE)
## 


###################################################
### code chunk number 18: dualKS.rnw:403-405 (eval = FALSE)
###################################################
## data <- data[,-ix.n]
## data.r <- sweep(data, 1, data.m, "/")


###################################################
### code chunk number 19: dualKS.rnw:411-416 (eval = FALSE)
###################################################
## data.r <- log(data.r, 2)
## tr <- dksTrain(data.r, class=pData(eset)[-ix.n,1], type="both")
## cl <- dksSelectGenes(tr, n=100)
## pr <- dksClassify(data.r, cl)
## plot(pr, actual=pData(eset)[-ix.n,1])


###################################################
### code chunk number 20: dualKS.rnw:421-432
###################################################
ix.n <- which(pData(eset)[,1] == "normal")
data <- exprs(eset)
data.m <- apply(data[,ix.n], 1, mean, na.rm=TRUE)
data <- data[,-ix.n]
data.r <- sweep(data, 1, data.m, "/")
data.r <- log(data.r, 2)

tr <- dksTrain(data.r, class=pData(eset)[-ix.n,1], type="both")
cl <- dksSelectGenes(tr, n=100)
pr <- dksClassify(data.r, cl)
plot(pr, actual=pData(eset)[-ix.n,1])


###################################################
### code chunk number 21: dualKS.rnw:440-442
###################################################
summary(pr, actual=pData(eset)[-ix.n,1])
show(pr)


###################################################
### code chunk number 22: dualKS.rnw:468-469
###################################################
pvalue.f <- pv.f


###################################################
### code chunk number 23: dualKS.rnw:472-473
###################################################
pvalue.f <- dksPerm(eset, 1, type="both", samples=500)


###################################################
### code chunk number 24: dualKS.rnw:482-483
###################################################
pvalue.f(pr@predictedScore)


###################################################
### code chunk number 25: dualKS.rnw:516-520 (eval = FALSE)
###################################################
## cls <- factor(sample(pData(eset)[,1], 300, replace=TRUE))
## sig.up <- sample(rownames(exprs(eset), 300))
## classifier <- dksCustomClass(upgenes=sig.up, upclass=cls)
## pr.cust <- dksClassify(eset, classifier)


###################################################
### code chunk number 26: dualKS.rnw:535-537
###################################################
results <- data.frame(pr@predictedClass, pr@scoreMatrix)
results
